turtles-own
[
  Electric-Car?                  ;; if true, the turtle has an Electric-Vehicle
  Petrol-Car?                    ;; if true, the turtle has an Petrol-Car
  Diesel-Car?                    ;; if true, the turtle has an Diesel-Car
  
  Innovator?                     ;; if true, turtle falls in innovator category
  Early-adopter?                 ;; if true, turtle falls in early adopter category
  Early-majority?                ;; if true, turtle falls in early majority category
  Late-majority?                 ;; if true, turtle falls in late marjority category
  Laggards?                      ;; if true, turtle falls in laggards category
  
  car-age                        ;; number of ticks since the car was bought
  car-lifetime                   ;; number of ticks the car 'survives'
  
  attitude-to-innovation         ;; Determines the innovation category & change threshold of turtle
  change-threshold               ;; The willingness of an agent to change its technology

  ev-list                        ;; Holds data on the amount of neighbors with an electric car for a specified period of ticks
  petrol-list                    ;; Holds data on the amount of neighbors with a petrol car for a specified period of ticks
  diesel-list                    ;; Holds data on the amount of neighbors with a diesel car for a specified period of ticks
  
  car-history-list               ;; Holds data on the history of car types of each turtle
]

;;;;;;;;;;;;;;;;;;;;;;;;
;;; Setup Procedures ;;;
;;;;;;;;;;;;;;;;;;;;;;;;

to setup
  clear-all
  ask patches [set pcolor white]
  setup-nodes
  setup-initial-car
  setup-network
  setup-innovation-preferences
  setup-lists
  reset-ticks
end

to setup-nodes
  set-default-shape turtles "circle"
  crt number-of-car-owners[
    setxy (random-xcor * 0.90) (random-ycor * 0.90) ]    ;; don't put any nodes real close to the edges
end

to setup-initial-car
  ask turtles [become-PETROLowner]
  ask n-of ((number-of-car-owners * initial-diesel-percentage) / 100) turtles with [Petrol-Car?] [become-DIESELowner]
  ;; it might be possible that a laggard start with an insuperior technology (i.e. diesel), while being surrounded by other technologies
  
  ask turtles [               
    if initial-car-age = 0 [set car-age 0]
    if initial-car-age = "random" [set car-age random car-lifetime]
    
    ]
  ;; this sets the turtles car properties  
end

to setup-network
  let num-links (average-links-per-car-owner * number-of-car-owners) / 2                   ;; divide by 2 as each link connects two nodes
  ask turtles [if count link-neighbors <= 0 
    [create-link-with min-one-of (other turtles with [not link-neighbor? myself]) [distance myself]]]  ;; make sure every node has at least 1 link
  while [count links <= num-links ]
      [ask  one-of turtles
           [ let choice (min-one-of (other turtles with [not link-neighbor? myself])
                 [distance myself])
      if choice != nobody [ create-link-with choice ]                                 ;; add connect links if node is unconnected
           ]
       ]
      
  ask links [ set color grey ]

  repeat 5
      [layout-spring turtles links 0.5 (world-width / (sqrt number-of-car-owners)) 1] ;; make network look bit nicer
end

to setup-innovation-preferences
  ask turtles [
    set attitude-to-innovation random-normal 0.5 0.16      ;; normal distribution N(0.5;0.16), this follows theory
    set change-threshold (round (attitude-to-innovation * count link-neighbors))  ;; threshold is now set to number of neighbors
    if change-threshold < 0 [set change-threshold 0]
    if change-threshold > count link-neighbors [set change-threshold count link-neighbors]
     
    ;; make sure no turtle is categorized yet   
    set Innovator? false                   
    set Early-adopter? false                
    set Early-majority? false             
    set Late-majority? false          
    set Laggards? false
    
    ;; arrange categorization of turtles
    if attitude-to-innovation >= 0.84 [set Laggards? true]
    if attitude-to-innovation < 0.84 [set Late-majority? true]
    if attitude-to-innovation < 0.50 [set Early-majority? true set late-majority? false]
    if attitude-to-innovation < 0.16 [set Early-adopter? true set early-majority? false]
    if attitude-to-innovation < 0.025 [set Innovator? true set early-adopter? false]
    
  ]
end

to setup-lists
  ask turtles [
    ;; record initial environment of turtle + own car type
    set ev-list (list 0)
    ifelse Petrol-Car? [set petrol-list (list (1 + count link-neighbors with [Petrol-Car?]))] [set petrol-list (list count link-neighbors with [Petrol-Car?])]
    ifelse Diesel-Car? [set diesel-list (list (1 + count link-neighbors with [Diesel-Car?]))] [set diesel-list (list count link-neighbors with [Diesel-Car?])]
    
    ;; record initial car type of turtle
    ifelse Petrol-Car? [set car-history-list (list "PETROL")]
      [ifelse Diesel-Car? [set car-history-list (list "DIESEL")]
        [show "ERROR in car history list"]
      ]
  ]
end



;;;;;;;;;;;;;;;;;;;;;;;;
;;;  Go Procedures   ;;;
;;;;;;;;;;;;;;;;;;;;;;;;

to go
  ask turtles [set car-age car-age + 1]
  ask turtles [update-memory]
  ask turtles with [car-age >= car-lifetime] [buy-car]
  tick
end

to update-memory                 ;; 10 ticks equal 1 year, this section does not cope with shortening 'car-owner-memory' during run time adequately
  ifelse Electric-Car? [set ev-list lput (1 + count link-neighbors with [Electric-Car?]) ev-list] [set ev-list lput count link-neighbors with [Electric-Car?] ev-list]
  ifelse Petrol-Car? [set petrol-list lput (1 + count link-neighbors with [Petrol-Car?]) petrol-list] [set petrol-list lput count link-neighbors with [Petrol-Car?] petrol-list]
  ifelse Diesel-Car? [set diesel-list lput (1 + count link-neighbors with [Diesel-Car?]) diesel-list] [set diesel-list lput count link-neighbors with [Diesel-Car?] diesel-list]
  
  
  if Innovator? [
    ;; limit list for innovators
    if length ev-list > (innovator-memory * 10) [set ev-list remove-item 0 ev-list]
    if length petrol-list > (innovator-memory * 10) [set petrol-list remove-item 0 petrol-list]
    if length diesel-list > (innovator-memory * 10) [set diesel-list remove-item 0 diesel-list]
  ]
  
  if Early-adopter? [
    ;; limit list for early-adopters
    if length ev-list > (early-adopter-memory * 10) [set ev-list remove-item 0 ev-list]
    if length petrol-list > (early-adopter-memory * 10) [set petrol-list remove-item 0 petrol-list]
    if length diesel-list > (early-adopter-memory * 10) [set diesel-list remove-item 0 diesel-list]
  ]
  
  if Early-majority? [
    ;; limit list for early-majority
    if length ev-list > (early-majority-memory * 10) [set ev-list remove-item 0 ev-list]
    if length petrol-list > (early-majority-memory * 10) [set petrol-list remove-item 0 petrol-list]
    if length diesel-list > (early-majority-memory * 10) [set diesel-list remove-item 0 diesel-list]
  ]
    
  if Late-majority? [
    ;; limit list for late-majority
    if length ev-list > (late-majority-memory * 10) [set ev-list remove-item 0 ev-list]
    if length petrol-list > (late-majority-memory * 10) [set petrol-list remove-item 0 petrol-list]
    if length diesel-list > (late-majority-memory * 10) [set diesel-list remove-item 0 diesel-list]
  ]
  
  if Laggards? [
    ;; limit list for laggards
    if length ev-list > (laggard-memory * 10) [set ev-list remove-item 0 ev-list]
    if length petrol-list > (laggard-memory * 10) [set petrol-list remove-item 0 petrol-list]
    if length diesel-list > (laggard-memory * 10) [set diesel-list remove-item 0 diesel-list]
  ]
end


to buy-car
  ifelse ticks < (years-to-ev-invention * 10) [
    ;; procedure in case ev is not evented yet
    ifelse Diesel-Car? [
      ifelse mean petrol-list >= change-threshold [become-PETROLowner] [become-DIESELowner]]
    [ifelse Petrol-Car? [
        ifelse mean diesel-list >= change-threshold [become-DIESELowner] [become-PETROLowner]]
    [show "DECISION ERROR IN BUYING CAR BEFORE EV INVENTION"]
    ]
    ]
    
    [
      ;; procedure in case ev is invented     
  ifelse Electric-Car? [
    if (mean diesel-list >= change-threshold) and (mean petrol-list >= change-threshold) [
      if Innovator? or early-adopter? [
        if mean diesel-list > mean petrol-list [become-PETROLowner]
        if mean diesel-list < mean petrol-list [become-DIESELowner]
        if mean diesel-list = mean petrol-list [ifelse random-float 1 <= 0.50 [become-DIESELowner] [become-PETROLowner]]]
      if early-majority? or late-majority? [
        ifelse random-float 1 <= 0.50 [become-DIESELowner] [become-PETROLowner]]
      if laggards? [
        if mean diesel-list < mean petrol-list [become-PETROLowner]
        if mean diesel-list > mean petrol-list [become-DIESELowner]
        if mean diesel-list = mean petrol-list [ifelse random-float 1 <= 0.50 [become-DIESELowner] [become-PETROLowner]]]]
    if (mean diesel-list >= change-threshold) and (mean petrol-list < change-threshold)[become-DIESELowner]        
    if (mean diesel-list < change-threshold) and (mean petrol-list >= change-threshold)[become-PETROLowner]        
    if (mean diesel-list < change-threshold) and (mean petrol-list < change-threshold)[become-EVowner]]
  
  [ifelse Diesel-Car? [
    if (mean ev-list >= change-threshold) and (mean petrol-list >= change-threshold) [
      if Innovator? or early-adopter? [
        if mean ev-list > mean petrol-list [become-PETROLowner]
        if mean ev-list < mean petrol-list [become-EVowner]
        if mean ev-list = mean petrol-list [ifelse random-float 1 <= 0.50 [become-EVowner] [become-PETROLowner]]]
      if early-majority? or late-majority? [
        ifelse random-float 1 <= 0.50 [become-EVowner] [become-PETROLowner]]
      if laggards? [
        if mean ev-list < mean petrol-list [become-PETROLowner]
        if mean ev-list > mean petrol-list [become-EVowner]
        if mean ev-list = mean petrol-list [ifelse random-float 1 <= 0.50 [become-EVowner] [become-PETROLowner]]]]
    if (mean ev-list >= change-threshold) and (mean petrol-list < change-threshold)[become-EVowner]        
    if (mean ev-list < change-threshold) and (mean petrol-list >= change-threshold)[become-PETROLowner]        
    if (mean ev-list < change-threshold) and (mean petrol-list < change-threshold)[become-DIESELowner]]
  
  [ifelse Petrol-Car? [
    if (mean ev-list >= change-threshold) and (mean diesel-list >= change-threshold) [
      if Innovator? or early-adopter? [
        if mean ev-list > mean diesel-list [become-DIESELowner]
        if mean ev-list < mean diesel-list [become-EVowner]
        if mean ev-list = mean diesel-list [ifelse random-float 1 <= 0.50 [become-EVowner] [become-DIESELowner]]]
      if early-majority? or late-majority? [
        ifelse random-float 1 <= 0.50 [become-EVowner] [become-DIESELowner]]
      if laggards? [
        if mean ev-list < mean diesel-list [become-DIESELowner]
        if mean ev-list > mean diesel-list [become-EVowner]
        if mean ev-list = mean diesel-list [ifelse random-float 1 <= 0.50 [become-EVowner] [become-DIESELowner]]]]
    if (mean ev-list >= change-threshold) and (mean diesel-list < change-threshold)[become-EVowner]        
    if (mean ev-list < change-threshold) and (mean diesel-list >= change-threshold)[become-DIESELowner]        
    if (mean ev-list < change-threshold) and (mean diesel-list < change-threshold)[become-PETROLowner]]
  [show "DECISION ERROR IN BUYING CAR AFTER EV INVENTION"]
  ]
  ]
    ]
  
  if Electric-Car? [set car-history-list lput "EV" car-history-list] 
  if Diesel-Car? [set car-history-list lput "DIESEL" car-history-list]
  if Petrol-Car? [set car-history-list lput "PETROL" car-history-list]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Car owner Procedures ;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to become-EVowner  
  set Electric-Car? true
  set Petrol-Car? false
  set Diesel-Car? false
  set color lime
  set size 2
  
  set car-age 0
  set car-lifetime random-normal (average-ev-car-life * 10) 20      ;;10 ticks equal 1 year --> car-lifetime now follows N(average car life, 2) year distribution
end

to become-PETROLowner 
  set Electric-Car? false
  set Petrol-Car? true
  set Diesel-Car? false
  set color red
  set size 2
    
  set car-age 0
  set car-lifetime random-normal (average-petrol-car-life * 10) 20      ;;10 ticks equal 1 year --> car-lifetime now follows N(average car life, 2) year distribution
end

to become-DIESELowner  
  set Electric-Car? false
  set Petrol-Car? false
  set Diesel-Car? true
  set color sky
  set size 2
   
  set car-age 0
  set car-lifetime random-normal (average-diesel-car-life * 10) 20      ;;10 ticks equal 1 year --> car-lifetime now follows N(average car life, 2) year distribution
end

 
@#$#@#$#@
GRAPHICS-WINDOW
687
10
1421
765
90
90
4.0
1
10
1
1
1
0
0
0
1
-90
90
-90
90
0
0
1
ticks
30.0

SLIDER
84
137
258
170
number-of-car-owners
number-of-car-owners
0
750
750
1
1
NIL
HORIZONTAL

BUTTON
133
36
196
69
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
83
85
146
118
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
0

BUTTON
181
85
258
118
go-once
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
0

SLIDER
83
296
312
329
initial-diesel-percentage
initial-diesel-percentage
0
100
29
1
1
%
HORIZONTAL

SLIDER
84
177
326
210
average-links-per-car-owner
average-links-per-car-owner
1
10
3
1
1
NIL
HORIZONTAL

SLIDER
325
253
560
286
average-petrol-car-life
average-petrol-car-life
5
20
12
1
1
year
HORIZONTAL

SLIDER
326
298
561
331
average-diesel-car-life
average-diesel-car-life
5
20
12
1
1
year
HORIZONTAL

SLIDER
327
348
539
381
average-ev-car-life
average-ev-car-life
5
20
15
1
1
year
HORIZONTAL

PLOT
1449
11
1877
253
Amount of Cars
ticks
amount
0.0
1000.0
0.0
100.0
true
true
"" ""
PENS
"EV" 1.0 0 -13840069 true "" "plot count turtles with [Electric-Car?]"
"Diesel" 1.0 0 -13791810 true "" "plot count turtles with [Diesel-Car?]"
"Petrol" 1.0 0 -2674135 true "" "plot count turtles with [Petrol-Car?]"

MONITOR
1451
272
1510
345
# EV
count turtles with [Electric-Car?]
0
1
18

MONITOR
1527
273
1615
346
# Diesel
count turtles with [Diesel-Car?]
0
1
18

MONITOR
1636
274
1723
347
# Petrol
count turtles with [Petrol-Car?]
0
1
18

PLOT
1451
364
1878
605
car percentages
ticks
% of cart type
0.0
1000.0
0.0
100.0
true
true
"" ""
PENS
"% EV" 1.0 0 -13840069 true "" "plot count turtles with [Electric-Car?] / count turtles * 100"
"% Diesel" 1.0 0 -13791810 true "" "plot count turtles with [Diesel-Car?] / count turtles * 100"
"% Petrol" 1.0 0 -2674135 true "" "plot count turtles with [Petrol-Car?] / count turtles * 100"

SLIDER
84
480
310
513
years-to-ev-invention
years-to-ev-invention
1
250
100
1
1
year
HORIZONTAL

CHOOSER
86
406
265
451
initial-car-age
initial-car-age
0 "random"
1

SLIDER
85
589
278
622
early-adopter-memory
early-adopter-memory
0
10
2
1
1
NIL
HORIZONTAL

SLIDER
86
633
280
666
early-majority-memory
early-majority-memory
0
10
4
1
1
NIL
HORIZONTAL

SLIDER
86
681
273
714
late-majority-memory
late-majority-memory
0
10
6
1
1
NIL
HORIZONTAL

SLIDER
86
727
258
760
laggard-memory
laggard-memory
0
10
8
1
1
NIL
HORIZONTAL

SLIDER
86
541
258
574
innovator-memory
innovator-memory
0.1
0.1
0.1
.1
1
NIL
HORIZONTAL

@#$#@#$#@
## WHAT IS IT?

This model represent the introduction of electric vehicles (green circles)) in a social network with petrol (red circles) and diesel car (blue circles) owners. The aim of this model is to study the effect of the introduction of an technology on the stability of the system. Hence, we explicitly mention that there is no power in the model to base policies upon etc.



## HOW IT WORKS

In a social setting, each agent owns eigther a petrol or a diesel car. Furthermore, each agent has an attitude to innovation, based on literature on the field of transition management. This makes the agent belong to one of five categories:
 - Innovator
 - Early adopter
 - Early majority
 - Late majority
 - Laggard

Depending on the catagory, each car owner has a memory in which it remembers the cars from its neighbors. When the car of the agent breaks, he has to buy a new car. He will base his decision on his memory, to see what types of cars are driven in his social network, his threshold of change, and on his category type. Based on his category type, the agent follows a specific decision procedure. Innovators and early adopters will, logically, easier choose a technology they rarely see than laggards.

After a certain period of time, 100 years (1000 ticks) by default, EV will be introduced. This way, agents have more technologies to choose from. Subject of study is how the EVs will diffuse through the social network.

 

## THINGS TO NOTICE

The EV development will start after a certain number of ticks, not right from the start. In this way, it is also possible to study the equilibrium before the EV is introduced to the system.


## EXTENDING THE MODEL

In extending the model, it would be nice to see how the system responds to multiple diffusions that follow on each other.


## IMPROVEMENTS FOR THE MODEL
In assigning agents their attitude to innovation, it seems like NetLogo is not appropriately dealing with the normal distribution. The effect is that the intended division of agents per adopter category is off. 

For example, when creating 750 agents, one would expect around 19 innovators (2,5%). However, it is extremely rare there will be more than 10.


## CREDITS AND REFERENCES

For helping develop this model, we would specifically like to thank Igor Nikolic and Joolie Kasmire for their supervision and bright ideas.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0.3
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="Experimental design output" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="6000"/>
    <metric>count turtles with [Electric-Car?]</metric>
    <metric>count turtles with [Petrol-Car?]</metric>
    <metric>count turtles with [Diesel-Car?]</metric>
    <metric>buyers-EV</metric>
    <metric>buyers-Petrol</metric>
    <metric>buyers-Diesel</metric>
    <enumeratedValueSet variable="average-petrol-car-life">
      <value value="12"/>
    </enumeratedValueSet>
    <steppedValueSet variable="average-links-per-car-owner" first="2" step="2" last="6"/>
    <enumeratedValueSet variable="average-diesel-car-life">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="early-adopter-memory">
      <value value="2"/>
    </enumeratedValueSet>
    <steppedValueSet variable="average-ev-car-life" first="12" step="3" last="18"/>
    <enumeratedValueSet variable="laggard-memory">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-car-age">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-diesel-percentage">
      <value value="29"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-car-owners">
      <value value="750"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="early-majority-memory">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="late-majority-memory">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovator-memory">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="years-to-ev-invention">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="500"/>
    <metric>count turtles with [Electric-Car?]</metric>
    <metric>count turtles with [Petrol-Car?]</metric>
    <metric>count turtles with [Diesel-Car?]</metric>
    <metric>buyers-EV</metric>
    <metric>buyers-Petrol</metric>
    <metric>buyers-Diesel</metric>
    <enumeratedValueSet variable="average-diesel-car-life">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovator-memory">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="late-majority-memory">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-ev-car-life">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="years-to-ev-invention">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-diesel-percentage">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-links-per-car-owner">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="early-adopter-memory">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="early-majority-memory">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-car-owners">
      <value value="750"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-petrol-car-life">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-car-age">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="laggard-memory">
      <value value="8"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 1.0 0.0
0.0 1 1.0 0.0
0.2 0 1.0 0.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
